.. _astrodrizzle:

**************************************
Primary User Interface: AstroDrizzle() 
**************************************
 
.. currentmodule:: drizzlepac.astrodrizzle

.. automodule:: drizzlepac.astrodrizzle
   
.. autofunction:: AstroDrizzle 
 
 
